#include "logqso.h"

#include <QTcpSocket>
#include <QString>
#include <QSettings>
#include <QStandardPaths>
#include <QDir>
#include <QDebug>

#include "JTDXMessageBox.hpp"

#include "logbook/adif.h"
#include "Configuration.hpp"
#include "Bands.hpp"

#include "ui_logqso.h"
#include "moc_logqso.cpp"

LogQSO::LogQSO(QSettings * settings, Configuration const * config, JTDXDateTime * jtdxtime, QWidget *parent)
  : QDialog(parent)
  , ui(new Ui::LogQSO)
  , m_settings (settings)
  , m_config {config}
  , m_jtdxtime {jtdxtime}
{
  ui->setupUi(this);
  ui->buttonBox->button(QDialogButtonBox::Ok)->setText(tr("&OK"));
  ui->buttonBox->button(QDialogButtonBox::Cancel)->setText(tr("&Cancel"));
//  setWindowTitle("JTDX " + versnumber.simplified () + " - Log QSO");
  setWindowTitle(QCoreApplication::applicationName () + " v" + QCoreApplication::applicationVersion () + " - Log QSO");

  loadSettings ();
}

LogQSO::~LogQSO ()
{
}

void LogQSO::loadSettings ()
{
  m_settings->beginGroup ("LogQSO");
  restoreGeometry (m_settings->value ("geometry", saveGeometry ()).toByteArray ());
  ui->cbTxPower->setChecked (m_settings->value ("SaveTxPower", false).toBool ());
  ui->cbComments->setChecked (m_settings->value ("SaveComments", false).toBool ());
  ui->cbEqslComments->setChecked (m_settings->value ("SaveEQSLComments", false).toBool ());
  m_txPower = m_settings->value ("TxPower", "").toString ();
  m_comments = m_settings->value ("LogComments", "").toString();
  m_eqslcomments = m_settings->value ("LogEQSLComments", "").toString();
  m_settings->endGroup ();
}

void LogQSO::storeSettings () const
{
  m_settings->beginGroup ("LogQSO");
  m_settings->setValue ("geometry", saveGeometry ());
  m_settings->setValue ("SaveTxPower", ui->cbTxPower->isChecked ());
  m_settings->setValue ("SaveComments", ui->cbComments->isChecked ());
  m_settings->setValue ("SaveEQSLComments", ui->cbEqslComments->isChecked ());
  m_settings->setValue ("TxPower", m_txPower);
  m_settings->setValue ("LogComments", m_comments);
  m_settings->setValue ("LogEQSLComments", m_eqslcomments);
  m_settings->endGroup ();
}

void LogQSO::initLogQSO(QString const& hisCall, QString const& hisGrid, QString mode,
                        QString const& rptSent, QString const& rptRcvd, QString const& name,
                        QDateTime const& dateTimeOn, QDateTime const& dateTimeOff,
                        Radio::Frequency dialFreq, bool autologging)
{
  m_send_to_eqsl=m_config->send_to_eqsl();
  ui->call->setText(hisCall);

  //-----> ja2bqx
      ui->search_Call->setText(hisCall);
      m_send_to_hamlog = m_config->send_to_hamlog();
      ui->lbl_thw->setText("");
      ui->lbl_send_to_thw->setText("");

       QString dataPath = QStandardPaths::writableLocation(QStandardPaths::DataLocation);
       QString iniFileName =dataPath + "\\JTDX.ini";
       QSettings settings(iniFileName, QSettings::IniFormat);
       settings.beginGroup("Configuration");
       m_HamlogHdb_path = settings.value("HamlogHdbDir").toString();
       settings.endGroup();
       ui->lbl_thw->setText(m_HamlogHdb_path);
  // <----- ja2bqx

  ui->grid->setText(hisGrid);
  ui->name->setText(name);
  ui->txPower->setText("");
  ui->comments->setText("");
  ui->eqslcomments->setText("");
  ui->lab11->setVisible(m_send_to_eqsl);
  ui->eqslcomments->setVisible(m_send_to_eqsl);
  ui->cbEqslComments->setVisible(m_send_to_eqsl);
  if (ui->cbTxPower->isChecked ()) ui->txPower->setText(m_txPower);
  if (ui->cbComments->isChecked ()) ui->comments->setText(m_comments);
  if (ui->cbEqslComments->isChecked ()) ui->eqslcomments->setText(m_eqslcomments);
  if(m_config->report_in_comments()) {
    QString t=mode;
    if(rptSent!="") t+="  Sent: " + rptSent;
    if(rptRcvd!="") t+="  Rcvd: " + rptRcvd;
    ui->comments->setText(t);
  }
  if(m_config->log_as_RTTY() and mode.left(3)=="JT9") mode="RTTY";
  ui->mode->setText(mode);
  ui->sent->setText(rptSent);
  ui->rcvd->setText(rptRcvd);
  ui->start_date_time->setDateTime (dateTimeOn);
  ui->end_date_time->setDateTime (dateTimeOff);
  m_dialFreq=dialFreq;
  m_myCall=m_config->my_callsign();
  m_myGrid=m_config->my_grid();
  m_tcp_server_name=m_config->tcp_server_name();
  m_tcp_server_port=m_config->tcp_server_port();
  m_enable_tcp_connection=m_config->enable_tcp_connection();
  m_debug=m_config->write_decoded_debug();
  ui->band->setText(m_config->bands ()->find (dialFreq));

  if(!autologging) {
	 show ();
  
     // -----> ja2bqx

     countryName="";
     jtdxEntity="";
     thwCode="";
     thwEntityName="";
     check_call="";
     search_call_str="";
     ui->jtdxEntity->setText("");
     ui->thwCode->setText("");
     ui->thwEntityName->setText("");

     len=0;
     ffp0=0;
     ffp1=0;
     ffp2=0;
     ffp3=0;
     ffp4=0;
     ffp5=0;

     search_call_str = ui->search_Call->text().trimmed();
     searchPrefix = search_call_str;

    QString txtStr = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ";
    QString Left_str;
    Left_str =  searchPrefix.left(1);

    // 1        10
    // 0123456789
    //
    // 11   16  17 20   21   22 24
    // ABCDEF   GHIJ    K    LMN
    //
    // 25     32  33 36
    // OPQRSTUV   WXYZ

    int ia = txtStr.indexOf(Left_str);

    if (ia>0 and ia<11){
        get_entity_from_Unique_callsign_Suuji ();
    } else if (ia>10 and ia<17){
        get_entity_from_Unique_callsign_ABCDEF ();
    } else if (ia>16 and ia<21){
        get_entity_from_Unique_callsign_GHIJ ();
    } else if (ia==21){
        get_entity_from_Unique_callsign_K ();
    } else if (ia>21 and ia<25){
        get_entity_from_Unique_callsign_LMN ();
    } else if (ia>24 and ia<33){
        get_entity_from_Unique_callsign_OPQRSTUV ();
    } else if (ia>32 and ia<37){
        get_entity_from_Unique_callsign_WXYZ ();
    }

    if(ffp0==0){
         LogBook logBook;
         logBook.init_thw();
         check_call = search_call_str;
         logBook.getDXCC(check_call,countryName);

// 擾ꂽ countryName  AS,JD/O,Ogasawara ̗lɂȂB
//void LogQSO::get_thwCode_from_jtdxEntity () ł
//    } else if(jtdxEntity == "JD/o") { Ȃ̂
//       jtdxEntity = jtdxEntity.toUcase();

         //ui->comments->setText(countryName);

         QStringList list = countryName.split(",");
         jtdxEntity = list[1].trimmed();
         //jtdxEntity = jtdxEntity.toUcase();B
         //ui->jtdxEntity->setText(jtdxEntity);

//cty.dat ł JD/o Ȃ̂
    int sp = jtdxEntity.indexOf("/");
    if (sp > 0) {
         QStringList list2 = jtdxEntity.split("/");
         jtdxEntity = list2[1].trimmed();
         QString ss0 = list2[0].trimmed();
         QString ss1 = list2[1].trimmed();
         jtdxEntity = ss0 + "/" + ss1.toLower();
       }
         ui->jtdxEntity->setText(jtdxEntity);
    }

    get_thwCode_from_jtdxEntity ();

     //jtdxEntity = "3V";
     ui->jtdxEntity->setText(jtdxEntity);
     ui->thwCode->setText(thwCode);
     ui->thwEntityName->setText(thwEntityName);

     if (m_send_to_hamlog) {
        ui->lbl_send_to_thw->setText("Auto send to Hamlog.hdb");
        ui->lbl_send_to_thw->setStyleSheet("background-color: rgb(0,255,0);");  //ΐF
        ui->lbl_thw->setStyleSheet("background-color: rgb(0,255,0);");

        get_hdb_keta_sub();
        get_hdb_rec_org_sub();

        } else {
         ui->lbl_send_to_thw->setText("Do not send to Hamlog.hdb");
         ui->lbl_send_to_thw->setStyleSheet("background-color: rgb(255,255,51);");  //F
         ui->lbl_thw->setStyleSheet("background-color: rgb(255,255,51);");
     }
     // <----- ja2bqx

  }  else {
	 accept();
  }
}

void LogQSO::accept()
{
  QString hisCall,hisGrid,mode,rptSent,rptRcvd,time,band;
  QString comments,eqslcomments,name;
  hisCall=ui->call->text();
  hisGrid=ui->grid->text();
  mode=ui->mode->text();
  rptSent=ui->sent->text();
  rptRcvd=ui->rcvd->text();
  m_dateTimeOn = ui->start_date_time->dateTime ();
  m_dateTimeOff = ui->end_date_time->dateTime ();
  band=ui->band->text();
  name=ui->name->text();
  m_txPower=ui->txPower->text();
  comments=ui->comments->text();
  m_comments=comments;
  eqslcomments=ui->eqslcomments->text();
  m_eqslcomments=eqslcomments;
  QString strDialFreq(QString::number(m_dialFreq / 1.e6,'f',6));

  //Log this QSO to ADIF file "wsjtx_log.adi"
  QString filename = "wsjtx_log.adi";  // TODO allow user to set
  ADIF adifile;
  auto adifilePath = QDir {QStandardPaths::writableLocation (QStandardPaths::DataLocation)}.absoluteFilePath ("wsjtx_log.adi");
  adifile.init(adifilePath);
  if (!adifile.addQSOToFile(hisCall,hisGrid,mode,rptSent,rptRcvd,m_dateTimeOn,m_dateTimeOff,band,comments,name,strDialFreq,m_myCall,m_myGrid,m_txPower,m_send_to_eqsl))
  {
      JTDXMessageBox::information_message(0,"","Cannot open file \"" + adifilePath + "\".");
   }

//Log this QSO to file "wsjtx.log"
  static QFile f {QDir {QStandardPaths::writableLocation (QStandardPaths::DataLocation)}.absoluteFilePath ("wsjtx.log")};
  if(!f.open(QIODevice::Text | QIODevice::Append)) {
    JTDXMessageBox::information_message(0,"","Cannot open file \"" + f.fileName () + "\" for append:" + f.errorString ());
  } else {
    QString logEntry=m_dateTimeOn.date().toString("yyyy-MM-dd,") +
      m_dateTimeOn.time().toString("hh:mm:ss,") + 
      m_dateTimeOff.date().toString("yyyy-MM-dd,") +
      m_dateTimeOff.time().toString("hh:mm:ss,") + hisCall + "," +
      hisGrid + "," + strDialFreq + "," + mode +
      "," + rptSent + "," + rptRcvd + "," + m_txPower +
      "," + comments + "," + name;
    QTextStream out(&f);
    out << logEntry <<
#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
                 endl;
#else
                 Qt::endl;
#endif

    f.close();

   // -----> ja2bqx
    m_strDialFreq = strDialFreq;

     put_thw_qsl_mark();

         if (m_send_to_hamlog) {
       append_Hamlog_hdb();
       rewrite_hdb_rec_sub();
    }
    // <----- ja2bqx


  }

//Clean up and finish logging
    QString myadif;
    QByteArray myadif2;
    myadif="<BAND:" + QString::number(band.length()) + ">" + band;
    myadif+=" <CALL:" + QString::number(hisCall.length()) + ">" + hisCall;
    myadif+=" <FREQ:" + QString::number(strDialFreq.length()) + ">" + strDialFreq;
    if (mode == "FT4") myadif+=" <MODE:4>MFSK <SUBMODE:"  + QString::number(mode.length()) + ">" + mode;
    else myadif+=" <MODE:"  + QString::number(mode.length()) + ">" + mode;
    myadif+=" <QSO_DATE:8>" + m_dateTimeOn.date().toString("yyyyMMdd");
    myadif+=" <TIME_ON:6>" + m_dateTimeOn.time().toString("hhmmss");
    myadif+=" <QSO_DATE_OFF:8>" + m_dateTimeOff.date().toString("yyyyMMdd");
    myadif+=" <TIME_OFF:6>" + m_dateTimeOff.time().toString("hhmmss");
    myadif+=" <RST_SENT:" + QString::number(rptSent.length()) + ">" + rptSent;
    myadif+=" <RST_RCVD:" + QString::number(rptRcvd.length()) + ">" + rptRcvd;
    if (m_txPower.length() >0) {
       myadif+=" <TX_PWR:" + QString::number(m_txPower.length()) + ">" + m_txPower;
    }
    if (hisGrid.length() > 3) {
      myadif+=" <GRIDSQUARE:" + QString::number(hisGrid.length()) + ">" + hisGrid;
    }
    if (name.length() > 0) {
      myadif+=" <NAME:" + QString::number(name.length()) + ">" + name;
    }
    if (comments.length() > 0) {
      myadif+=" <COMMENT:" + QString::number(comments.length()) + ">" + comments;
    }
    if (m_send_to_eqsl) {
      myadif+=" <EQSL_QSL_SENT:1>Y <EQSL_QSLSDATE:8>" + m_jtdxtime->currentDateTimeUtc2().toString("yyyyMMdd");
    }
    myadif+=" <EOR> ";
    myadif2 = myadif.trimmed().toUtf8();

  Q_EMIT acceptQSO (m_dateTimeOff, hisCall, hisGrid, m_dialFreq, mode, rptSent, rptRcvd, m_txPower, comments, name, m_dateTimeOn, eqslcomments, myadif2);
  
  myadif="<command:3>Log <parameters:" + QString::number(myadif.length()) + "> " + myadif;
  myadif2 = myadif.toUtf8();
  if (m_enable_tcp_connection){
    QTcpSocket socket;
    static QFile f2 {QDir {QStandardPaths::writableLocation (QStandardPaths::DataLocation)}.absoluteFilePath ("tcptrace.txt")};
    bool fopen = false;
    if(m_debug) { 
      if(f2.open(QIODevice::WriteOnly | QIODevice::Text | QIODevice::Append)) fopen = true;
      else {
      JTDXMessageBox::warning_message (0, "", " File Open Error "
                                  , tr ("Cannot open \"%1\" for append: %2")
                                  .arg (f2.fileName ()).arg (f2.errorString ()));
      }
    }
    if(fopen)  { QTextStream out2(&f2); out2 << m_jtdxtime->currentDateTimeUtc2().toString("yyyyMMdd_hhmmss.zzz") << "(" << m_jtdxtime->GetOffset() << ")" << " Connecting to " << m_tcp_server_name << ":" << m_tcp_server_port <<
#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
                 endl;
#else
                 Qt::endl;
#endif
 }
    socket.connectToHost(m_tcp_server_name, m_tcp_server_port);
    if (socket.waitForConnected(1000)) {
      socket.write(myadif2);
      if(fopen) { QTextStream out2(&f2); out2 << m_jtdxtime->currentDateTimeUtc2().toString("yyyyMMdd_hhmmss.zzz") << "(" << m_jtdxtime->GetOffset() << ")" << " Host connected, sent message: " << myadif2 <<
#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
                 endl;
#else
                 Qt::endl;
#endif
 }
      if (socket.waitForReadyRead(1000)){
        myadif2 = socket.readAll();
        if(fopen) { QTextStream out2(&f2); out2 << m_jtdxtime->currentDateTimeUtc2().toString("yyyyMMdd_hhmmss.zzz") << "(" << m_jtdxtime->GetOffset() << ")" << " Received response from host: " << myadif2 <<
#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
                 endl;
#else
                 Qt::endl;
#endif
 }
        if (myadif2.left(3) == "NAK") {
          JTDXMessageBox::critical_message(0, "",myadif2 + " QSO data rejected by external software");
        }
      } else {
      if(fopen) { QTextStream out2(&f2); out2 << m_jtdxtime->currentDateTimeUtc2().toString("yyyyMMdd_hhmmss.zzz") << "(" << m_jtdxtime->GetOffset() << ")" << " Getting response from host is timed out" <<
#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
                 endl;
#else
                 Qt::endl;
#endif
 }
      }  
      socket.close();
    } else {
      if(fopen) { QTextStream out2(&f2); out2 << m_jtdxtime->currentDateTimeUtc2().toString("yyyyMMdd_hhmmss.zzz") << "(" << m_jtdxtime->GetOffset() << ")" << " Host connection timed out" <<
#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
                 endl;
#else
                 Qt::endl;
#endif
 }
      JTDXMessageBox::critical_message(0, "", "TCP QSO data transfer: " + socket.errorString());
    }
    if(fopen) f2.close();
  }
  QDialog::accept();
}

// closeEvent is only called from the system menu close widget for a
// modeless dialog so we use the hideEvent override to store the
// window settings
void LogQSO::hideEvent (QHideEvent * e)
{
  storeSettings ();
  QDialog::hideEvent (e);
}

// -----> ja2bqx

void LogQSO::get_hdb_keta_sub()
{
    unsigned char buf[500];
    int i , size;
    FILE *fp;
    char *fname = m_HamlogHdb_path.toUtf8().data();
     fp = fopen( fname, "rb" );
     size = fread( buf, sizeof( unsigned char ), 500, fp );
     his_len = buf[304];
     my_len = buf[336];
     freq_len = buf[368];
     mode_len = buf[400];
     name_len = buf[432];
     qth_len = buf[464];
     rmk_len = buf[496];

     QString strs0 = QString::number(buf[304]);  //his  3
     QString strs1 = QString::number(buf[336]);  //my   3
     QString strs2 = QString::number(buf[368]);  //freq 7
     QString strs3 = QString::number(buf[400]);  //mode 4
     QString strs4 = QString::number(buf[432]);  //name 12
     QString strs5 = QString::number(buf[464]);  //qth  28
     QString strs6 = QString::number(buf[496]);  //rmk  54
     fclose( fp );
}


void LogQSO::get_hdb_rec_org_sub()

{
    unsigned int buf1[4];
    unsigned int buf2[4];
    FILE *file;
    char *fname = m_HamlogHdb_path.toUtf8().data();
    file = fopen( fname, "rb" );
    fread(buf1,sizeof(int),sizeof(buf1)/sizeof(int),file);
    fread(buf2,sizeof(int),sizeof(buf2)/sizeof(int),file);
    fclose(file);
    hdb_header = buf1[0];
    hdb_rec_org = buf1[1];      //org
    hdb_rec_new = buf1[1] + 1;  //new

    QString strn1 = QString::number(hdb_rec_org);
    QString strn2 = QString::number(hdb_rec_new);
}


void LogQSO::rewrite_hdb_rec_sub()  //1A 13 02 10    9F BB 0D 00
{
    FILE* fa11;
    char *fname = m_HamlogHdb_path.toUtf8().data();
    fa11 = fopen(fname, "rb+" );
    fwrite( &hdb_header, 1, 4, fa11 ); //(1A 13 02 10)16 = (268571418)10
    fwrite( &hdb_rec_new, 1, 4, fa11 );
    fclose( fa11 );
 }

void LogQSO::append_Hamlog_hdb()

{
    FILE* fp;
    char *fname = m_HamlogHdb_path.toUtf8().data();
    fp = fopen(fname, "ab" ); //ǉo

    if( fp == NULL ){
        fputs( "t@CI[vɎs܂B\n", stderr );
        exit( EXIT_FAILURE );
    }


// prnf[^Rڈȍ~͐擪Ɂ@QO@ǉB@Ō㕔ɂ͉ȂB
 unsigned int num_32 = 32;
 fwrite( &num_32, 1, 1, fp );

  QString kuuhaku_str = " ";
 QString str10= ui->search_Call->text();  //R[TCPŶŏCB2020.01.28
 QString str11 = kuuhaku_str.repeated(20);  //2020.01.28
 QString str12= str10 + str11;
 QString str13 = str12.left(20);  //2020.01.28
 QByteArray ba1 = str13.toLatin1();
 const char *c_str14 = ba1.data();
 fwrite( c_str14,1, 20,fp );  //2020.01.28


 //date 2
 QString end_date_time_str = ui->end_date_time->text(); //14/02/2019 23:31:59
 QStringList list0 = end_date_time_str.split(" ");
 QString date_str = list0[0];                  //14/02/2019
 QString time_str = list0[1];                  //23:31:59

  //date

//14/02/2019
 QString date_dd_str = date_str.left(2);                  //14   split ĂȂH
 QString date_mm_str = date_str.mid(3, 2);                  //02
 QString date_yyyy_str = date_str.right(2);                //2019
 QString date_yy_str2 = date_yyyy_str.right(2);     //19
 QString date_yy_str1 = date_yyyy_str.left(2);      //20

 unsigned int date_num_yy1 = date_yy_str1.toInt();
 unsigned int date_num_yy2 = date_yy_str2.toInt();
 unsigned int date_num_mm = date_mm_str.toInt();
 unsigned int date_num_dd = date_dd_str.toInt();

 fwrite( &date_num_yy1, 1, 1, fp ); //20
 fwrite( &date_num_yy2, 1, 1, fp ); //19
 fwrite( &date_num_mm, 1, 1, fp ); //02
 fwrite( &date_num_dd, 1, 1, fp ); //14

// time
 //23:31:59
 QString time_hh_str = time_str.left(2);                  //23
 QString time_mm_str = time_str.mid(3,2);                  //31

 /*
 QStringList list02 = time_str.split(":");
 QString time_hh_str = list02[0];                  //23
 QString time_mm_str = list02[1];                  //31
 */


int time_num_hh = time_hh_str.toInt();
 int time_num_mm = 128 + time_mm_str.toInt();
 fwrite( &time_num_hh, 1, 1, fp );
 fwrite( &time_num_mm, 1, 1, fp );

  //code
 QString str40 = ui->thwCode->text();
 QString str41 = kuuhaku_str.repeated(6);
 QString str42= str40 + str41;
 QString str43 = str42.left(6);
 QByteArray ba4 = str43.toLatin1();
 const char *c_str44 = ba4.data();
 fwrite( c_str44,1, 6,fp );

 //grid
 QString str50 = ui->grid->text();
 QString str51 = kuuhaku_str.repeated(6);
 QString str52= str50 + str51;
 QString str53 = str52.left(6);
 QByteArray ba5 = str53.toLatin1();
 const char *c_str54 = ba5.data();
 fwrite( c_str54,1, 6,fp );

 //qsl
 QString str60 = ui->Qsl_Mark->text();
 QString str61 = kuuhaku_str.repeated(3);
 QString str62= str60 + str61;
 QString str63 = str62.left(3);
 QByteArray ba6 = str63.toLatin1();
 const char *c_str64 = ba6.data();
 fwrite( c_str64,1, 3,fp );

 //char DX flag; 2 byte (08 00)16
 unsigned int num_1 = 8;
 fwrite( &num_1, 1, 1, fp );

 unsigned int num_2 = 0;
 fwrite( &num_2, 1, 1, fp );

 //hiss
 QString str80 = ui->sent->text();
 QString str81 = kuuhaku_str.repeated(his_len);
 QString str82 = str80 + str81;
 QString str83 = str82.left(his_len);
 QByteArray ba8 = str83.toLatin1();
 const char *c_str84 = ba8.data();
 fwrite( c_str84,1, his_len,fp );

 //myrs
 QString str90 = ui->rcvd->text();
 QString str91 = kuuhaku_str.repeated(my_len);
 QString str92 = str90 + str91;
 QString str93 = str92.left(my_len);
 QByteArray ba9 = str93.toLatin1();
 const char *c_str94 = ba9.data();
 fwrite( c_str94,1, my_len,fp );

 //freq
 QString str30 = m_strDialFreq;
 //QString str30 = "14.074";
 //ui->exchSent->setText(str30);

 QString str31 = kuuhaku_str.repeated(freq_len);
 QString str32= str30 + str31;
 QString str33 = str32.left(freq_len);
 QByteArray ba3 = str33.toLatin1();
 const char *c_str34 = ba3.data();
 fwrite( c_str34,1, freq_len,fp );

//mode
 QString sts10 = ui->mode->text();
 QString sts11 = kuuhaku_str.repeated(mode_len);
 QString sts12 = sts10 + sts11;
 QString sts13 = sts12.left(mode_len);
 QByteArray bb1 = sts13.toLatin1();
 const char *c_sts14 = bb1.data();
 fwrite( c_sts14,1, mode_len,fp );

//name
 QString sts20 = ui->name->text();
 QString sts21 = kuuhaku_str.repeated(name_len);
 QString sts22 = sts20 + sts21;
 QString sts23 = sts22.left(name_len);
 QByteArray bb2 = sts23.toLatin1();
 const char *c_sts24 = bb2.data();
 fwrite( c_sts24,1, name_len,fp );

 //qth
  QString sts30 = ui->thwEntityName->text();
  QString sts31 = kuuhaku_str.repeated(qth_len);
  QString sts32 = sts30 + sts31;
  QString sts33 = sts32.left(qth_len);
  QByteArray bb3 = sts33.toLatin1();
  const char *c_sts34 = bb3.data();
  fwrite( c_sts34,1, qth_len,fp );

   //rmk1
   QString sts41 = kuuhaku_str.repeated(rmk_len);
   QByteArray bb4 = sts41.toLatin1();
   const char *c_sts44 = bb4.data();
   fwrite( c_sts44,1, rmk_len,fp );

   //rmk2
    QString sts51 = kuuhaku_str.repeated(rmk_len);
    QByteArray bb5 = sts51.toLatin1();
    const char *c_sts54 = bb5.data();
    fwrite( c_sts54,1, rmk_len,fp );

     if( fclose( fp ) == EOF ){
       fputs( "t@CN[YɎs܂B\n", stderr );
       exit( EXIT_FAILURE );
    }

}


void LogQSO::get_thw_qsl_mark()
{
       QString str; QFile file("thw_qsl_mark.txt"); //jtdx.exe ̂tH_B

      if (!file.open(QIODevice::ReadOnly))
       {
       }
         QTextStream in(&file);
           in >> Qsl_Mark_str;

           if(Qsl_Mark_str=="")
          {
               Qsl_Mark_str = "J";
          }
           ui->Qsl_Mark->setText(Qsl_Mark_str);
}

void LogQSO::put_thw_qsl_mark()
{
      QFile file("thw_qsl_mark.txt"); //jtdx.exe ̂tH_B
      if (!file.open(QIODevice::WriteOnly))
      {
          return;
      }
      QTextStream out(&file);
      Qsl_Mark_str = ui->Qsl_Mark->text().trimmed();
      out << Qsl_Mark_str << endl;
}

// ---> ja2bqx

//cty-3020  20201205

void LogQSO::get_entity_from_Unique_callsign_Suuji ()
{
    if(searchPrefix == "3D2CR") {
        jtdxEntity = "3D2/c";
        ffp0 = 1;
    } else if(searchPrefix == "3D2RI") {
        jtdxEntity = "3D2/r";
        ffp0 = 1;
    } else if(searchPrefix == "3Y0E") {
        jtdxEntity = "3Y/b";
        ffp0 = 1;
    } else if(searchPrefix == "3Y0X") {
        jtdxEntity = "3Y/p";
        ffp0 = 1;
    } else if(searchPrefix == "4U1ITU") {
        jtdxEntity = "4U1I";
        ffp0 = 1;
    } else if(searchPrefix == "4U1WRC") {
        jtdxEntity = "4U1I";
        ffp0 = 1;
    } else if(searchPrefix == "4U1UN") {
        jtdxEntity = "4U1U";
        ffp0 = 1;
    } else if(searchPrefix == "4U75UN") {
        jtdxEntity = "4U1U";
        ffp0 = 1;
    } else if(searchPrefix == "4U0R") {
        jtdxEntity = "OE";
        ffp0 = 1;
    } else if(searchPrefix == "4U1A") {
        jtdxEntity = "OE";
        ffp0 = 1;
    } else if(searchPrefix == "4U1VIC") {
        jtdxEntity = "OE";
        ffp0 = 1;
    } else if(searchPrefix == "4U2STAYHOME") {
        jtdxEntity = "OE";
        ffp0 = 1;
    } else if(searchPrefix == "4U2U") {
        jtdxEntity = "OE";
        ffp0 = 1;
    } else if(searchPrefix == "4U75A") {
        jtdxEntity = "OE";
        ffp0 = 1;
    } else if(searchPrefix == "4Y1A") {
        jtdxEntity = "OE";
        ffp0 = 1;
    } else if(searchPrefix == "9M4CAK") {
        jtdxEntity = "9M6";
        ffp0 = 1;
    } else if(searchPrefix == "9M4CPT") {
        jtdxEntity = "9M6";
        ffp0 = 1;
    } else if(searchPrefix == "9M4JAY") {
        jtdxEntity = "9M6";
        ffp0 = 1;
    } else if(searchPrefix == "9M4CCB") {
        jtdxEntity = "9M6";
        ffp0 = 1;
    } else if(searchPrefix == "9M4CKT") {
        jtdxEntity = "9M6";
        ffp0 = 1;
    } else if(searchPrefix == "9M4CRB") {
        jtdxEntity = "9M6";
        ffp0 = 1;
    } else if(searchPrefix == "9M4CRP") {
        jtdxEntity = "9M6";
        ffp0 = 1;
    } else if(searchPrefix == "8J1RL") {
        jtdxEntity = "CE9";
        ffp0 = 1;
    } else if(searchPrefix == "2E0CVN/NHS") {
        jtdxEntity = "G";
        ffp0 = 1;
    } else if(searchPrefix == "2I0NGM/NHS") {
        jtdxEntity = "GI";
        ffp0 = 1;
    } else if(searchPrefix == "2M0BDR") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "2M0BDT") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "2M0CPN") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "2M0GFC") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "2M0SEG") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "2M0SPX") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "2M0ZET") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "4U0WFP") {
        jtdxEntity = "I";
        ffp0 = 1;
    } else if(searchPrefix == "4U5F") {
        jtdxEntity = "I";
        ffp0 = 1;
    } else if(searchPrefix == "4U75B") {
        jtdxEntity = "I";
        ffp0 = 1;
    } else if(searchPrefix == "4U1WB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "4U0R") {
        jtdxEntity = "OE";
        ffp0 = 1;
    } else if(searchPrefix == "4U1A") {
        jtdxEntity = "OE";
        ffp0 = 1;
    } else if(searchPrefix == "4U1VIC") {
        jtdxEntity = "OE";
        ffp0 = 1;
    } else if(searchPrefix == "4U2STAYHOME") {
        jtdxEntity = "OE";
        ffp0 = 1;
    } else if(searchPrefix == "4U2U") {
        jtdxEntity = "OE";
        ffp0 = 1;
    } else if(searchPrefix == "4U75A") {
        jtdxEntity = "OE";
        ffp0 = 1;
    } else if(searchPrefix == "4Y1A") {
        jtdxEntity = "OE";
        ffp0 = 1;
    }
}



void LogQSO::get_entity_from_Unique_callsign_ABCDEF ()
{
    if(searchPrefix == "C7A") {
        jtdxEntity = "OE";
        ffp0 = 1;
    } else if(searchPrefix == "BS7H") {
        jtdxEntity = "BS7";
        ffp0 = 1;
    } else if(searchPrefix == "DP0GVN") {
        jtdxEntity = "CE9";
        ffp0 = 1;
    } else if(searchPrefix == "DP1POL") {
        jtdxEntity = "CE9";
        ffp0 = 1;
    } else if(searchPrefix == "E51PT") {
        jtdxEntity = "E5/n";
        ffp0 = 1;
    } else if(searchPrefix == "E51WL") {
        jtdxEntity = "E5/n";
        ffp0 = 1;
    } else if(searchPrefix == "EA2EZ/P") {
        jtdxEntity = "EA";
        ffp0 = 1;
    } else if(searchPrefix == "EA5CC/P") {
        jtdxEntity = "EA";
        ffp0 = 1;
    } else if(searchPrefix == "EA5EZ/P") {
        jtdxEntity = "EA";
        ffp0 = 1;
    } else if(searchPrefix == "EA5URE/P") {
        jtdxEntity = "EA";
        ffp0 = 1;
    } else if(searchPrefix == "EA5ZD/URE") {
        jtdxEntity = "EA";
        ffp0 = 1;
    } else if(searchPrefix == "EA9HU") {
        jtdxEntity = "EA";
        ffp0 = 1;
    } else if(searchPrefix == "EA2EJO/8") {
        jtdxEntity = "EA8";
        ffp0 = 1;
    } else if(searchPrefix == "EA8VK/URE") {
        jtdxEntity = "EA8";
        ffp0 = 1;
    } else if(searchPrefix == "FO/F6BCW") {
        jtdxEntity = "FO/m";
        ffp0 = 1;
    } else if(searchPrefix == "AA0O") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AA2IL") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AA4DD") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AA4Q") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AA5JF") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AA8R") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AB4B") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AB4GG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AB4IQ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AB8RL") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AB8YZ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AC4CA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AC4G") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AC4GW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AC6WI") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AC6ZM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AC7AF") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AC8Y") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AC9TO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AD1C") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AD4EB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AD4TA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AD8J") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AE4ED") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AE6JV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AE7AP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AF4T") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AG4W") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AH0U") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AH2AV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AH2O") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AH6FF") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AI4DB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AI6O") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AI9K") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AJ4A") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AJ4F") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AJ7G") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AL0A") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AL1VE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AL4B") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AL7CR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AL7RF") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AA1AB") {
        jtdxEntity = "KH0";
        ffp0 = 1;
    } else if(searchPrefix == "AI7CF") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "C7A") {
        jtdxEntity = "OE";
        ffp0 = 1;
    }
}



void LogQSO::get_entity_from_Unique_callsign_GHIJ ()
{
    if(searchPrefix == "GB3NGI") {
        jtdxEntity = "GI";
        ffp0 = 1;
    } else if(searchPrefix == "GB5NHS") {
        jtdxEntity = "GI";
        ffp0 = 1;
    } else if(searchPrefix == "GB8NHS") {
        jtdxEntity = "GI";
        ffp0 = 1;
    } else if(searchPrefix == "GB9AFD") {
        jtdxEntity = "GI";
        ffp0 = 1;
    } else if(searchPrefix == "GH5DX/NHS") {
        jtdxEntity = "GJ";
        ffp0 = 1;
    } else if(searchPrefix == "GB2ELH") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB3LER") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB3LER/B") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB4LER") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM0AVR") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM0CXQ") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM0EKM") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM0GFL") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM0ILB") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM0JDB") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM1FGN") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM1KKI") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM1ZNR") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM3WHT") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM3ZET") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM4IPK") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM4JPI") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM4LBE") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM4LER") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM4PXG") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM4SLV") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM4SSA") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM4WXQ") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM4ZHL") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM6RQW") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM6YQA") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM7AFE") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM7GWW") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM8LNH") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM8MMA") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM8YEC") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GS3ZET") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB0CSG") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB0SJR") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB1RST") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB2ELH") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB2FEA") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB2JCM") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB2OWM") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB2SBS") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB3ANG") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB3LER") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB3LER/B") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB4LER") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM0WED/NHS") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM3YDN/NHS") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM4SQM/NHS") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM4SQN/NHS") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM6JNJ/NHS") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB100RS") {
        jtdxEntity = "GU";
        ffp0 = 1;
    } else if(searchPrefix == "GB1LWF") {
        jtdxEntity = "GW";
        ffp0 = 1;
    } else if(searchPrefix == "GB1RTF") {
        jtdxEntity = "GW";
        ffp0 = 1;
    } else if(searchPrefix == "GB1WIW") {
        jtdxEntity = "GW";
        ffp0 = 1;
    } else if(searchPrefix == "GB2VK") {
        jtdxEntity = "GW";
        ffp0 = 1;
    } else if(searchPrefix == "HK0TU") {
        jtdxEntity = "HK0/m";
        ffp0 = 1;
    } else if(searchPrefix == "IT9ELM/0") {
        jtdxEntity = "I";
        ffp0 = 1;
    } else if(searchPrefix == "IT9PQJ/0") {
        jtdxEntity = "I";
        ffp0 = 1;
    } else if(searchPrefix == "II0GD") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "II0ICH") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "II0IDP") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "II0M") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0AG") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0AH") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0AI") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0AK") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0AK/P") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0AL") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0AM") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0EH") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0HO") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0ID") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0JY") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0NU") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0NV") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0NV/P") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0OG") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0OH") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0QP") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0SS") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IY0GA") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ6KX/9") {
        jtdxEntity = "I";
        ffp0 = 1;
    } else if(searchPrefix == "JG8NQJ/JD1") {
        jtdxEntity = "JD/m";
        ffp0 = 1;
    } else if(searchPrefix == "JW/LB2PG") {
        jtdxEntity = "JW";
        ffp0 = 1;
    } else if(searchPrefix == "G8ERJ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "HF0POL") {
        jtdxEntity = "VP8/h";
        ffp0 = 1;
    }
}



void LogQSO::get_entity_from_Unique_callsign_K ()
{
    if(searchPrefix == "KC4AAA") {
        jtdxEntity = "CE9";
        ffp0 = 1;
    } else if(searchPrefix == "KC4AAC") {
        jtdxEntity = "CE9";
        ffp0 = 1;
    } else if(searchPrefix == "KC4USB") {
        jtdxEntity = "CE9";
        ffp0 = 1;
    } else if(searchPrefix == "KC4USV") {
        jtdxEntity = "CE9";
        ffp0 = 1;
    } else if(searchPrefix == "K0ACP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K0EJ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K0IP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K0LUZ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K0NW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K0PJ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K0SN") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K0TQ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K0ZR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K1DC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K1DW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K1GU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K1KD") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K1LT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K1OU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K2DRH") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K2DSW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K2GMY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K2KR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K2PM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K2PO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K2RD") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K2RP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K2UR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K2VV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K3DMG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K3EST") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K3IE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K3JWI") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K3NT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K3PA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K3WT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K3WYC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K3YP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4AB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4AFE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4AMC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4AVX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4BWP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4BX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4CWW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4FN") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4FT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4IE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4IU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4OAQ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4OWR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4RO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4TCG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4TZ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4UU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4WG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4WI") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4WW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4XU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4YJ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4ZGB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K5EK") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K5GDX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K5KG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K5OA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K5VIP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K5ZD") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K6BFL") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K6XT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K7ABV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K7BG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K7BV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K7CS") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K7DR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K7IA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K7MSO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K7OM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K7QA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K7SCX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K7SV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K7TD") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K8AC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K8ARY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K8CN") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K8IA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K8JQ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K8LBQ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K8LF") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K8LS") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K8NYG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K8PO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K8TE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K8TR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K9CHP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K9DR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K9DU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K9GWS") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K9JF") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K9JM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K9OM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K9OZ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K9RS") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K9WA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K9WZB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K9YC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KA3MTT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KA4GAV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KA4OTB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KA8HDE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KA8Q") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KA9FOX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KA9VVQ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KB4QZH") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KB7Q") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KB9S") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KC2LM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KC4HW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KC4NX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KC4SAW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KC4TEO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KC4WQ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KC7QY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KC8GCR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KC8J") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KC9K") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KD0EE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KD2KW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KD4EE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KD4TRG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KD5DD") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KE0L") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KE0YI") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KE1B") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KE2VB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KE3K") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KE4KY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KE8FT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KF4AV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KF5BA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KF5MU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KG0F") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KG4CUY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KG5HVO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KH2BR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KH2D") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KH2GM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KH2PM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KH2TJ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KH6CT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KH6DHK") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KH6M") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KH6VM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KH6XS") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KI6DY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KI6QDH") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KI7ID") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KJ4AOM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KJ4IWZ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KJ4M") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KJ9C") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KK9A") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KK9N") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KL0SS") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KL1SE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KL2AX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KL2RA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KL4CZ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KL7DJ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KL7HQR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KL7IKV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KL7NW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KL7QW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KL7SK") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KM4FO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KM4JA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KM6Z") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KM7W") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KN1CBR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KN8U") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KO4OL") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KO8SCA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KO8V") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KO9V") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KP3M") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KP4MD") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KR4F") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KS0CW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KS4X") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KS7T") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KS9W") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KT3M") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KT4O") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KT4RR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KU1CW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KU8E") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KV4T") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KV8S") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KW4J") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KW7D") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KW7Q") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KX2P") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KX4X") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KY0Q") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KZ1W") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KZ4KX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KZ9V") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KG4NE") {
        jtdxEntity = "KG4";
        ffp0 = 1;
    } else if(searchPrefix == "K8RN") {
        jtdxEntity = "KH0";
        ffp0 = 1;
    } else if(searchPrefix == "KI5DQL") {
        jtdxEntity = "KH0";
        ffp0 = 1;
    } else if(searchPrefix == "KG6DX") {
        jtdxEntity = "KH2";
        ffp0 = 1;
    } else if(searchPrefix == "KG6JDX") {
        jtdxEntity = "KH2";
        ffp0 = 1;
    } else if(searchPrefix == "KH6KK") {
        jtdxEntity = "KH2";
        ffp0 = 1;
    } else if(searchPrefix == "KN4LVP") {
        jtdxEntity = "KH2";
        ffp0 = 1;
    } else if(searchPrefix == "K1TOR") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "K2GT") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "K4JMB") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "K4XV") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "K5PKT") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "K6HNL") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "K9FD") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KB1KAC") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KB3HXI") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KB5OXR") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KC0HFI") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KC2CLQ") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KC6MCC") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KC8JNV") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KD0JNO") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KE0KIE") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KE7DES") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KE7DET") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KF4UJC") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KF5JFX") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KF6OHL") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KG5CH") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KG5CNO") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KG5IVP") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KG7TSD") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KH0WJ") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KH3AE") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KJ6CPN") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KJ6CQT") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KJ6FDF") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KK6DWS") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KL3JC") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KM6RWE") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KM6UVP") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KD2UVU") {
        jtdxEntity = "KH8";
        ffp0 = 1;
    } else if(searchPrefix == "K9CS/KH8S") {
        jtdxEntity = "KH8/s";
        ffp0 = 1;
    } else if(searchPrefix == "K0ESQ") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "K1IEE") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "K1LQ") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "K1TMT") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "K5RD") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "K7BUF") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "K7CAP") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "K7VRK") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KA1NCN") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KB5NOW") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KB7RWK") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KB9THD") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KC0EFL") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KC1LVR") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KC3BWW") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KC3NUH") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KC5NHL") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KC7DNT") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KC9IKH") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KC9SXX") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KD5MQC") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KD5SHW") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KD8KQL") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KD9QKS") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KE0PRX") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KE5WGZ") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KE7ZXH") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KF7ARC") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KF7FLL") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KF7FLM") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KF7GCF") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KF7ING") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KF7ITN") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KF7KTH") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KF7WVE") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KG7OYE") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KG7ZEV") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KI4FJK") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KI7BKQ") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KJ6RFQ") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KK6SNS") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KM6YOD") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KN4ENR") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KN4LJD") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KW4XD") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "K5KUB") {
        jtdxEntity = "KP2";
        ffp0 = 1;
    } else if(searchPrefix == "K9VV") {
        jtdxEntity = "KP2";
        ffp0 = 1;
    } else if(searchPrefix == "KV4CF") {
        jtdxEntity = "KP2";
        ffp0 = 1;
    } else if(searchPrefix == "KV4KW") {
        jtdxEntity = "KP2";
        ffp0 = 1;
    } else if(searchPrefix == "KB2BVX") {
        jtdxEntity = "KP4";
        ffp0 = 1;
    } else if(searchPrefix == "KB3TTV") {
        jtdxEntity = "KP4";
        ffp0 = 1;
    } else if(searchPrefix == "KC2GRZ") {
        jtdxEntity = "KP4";
        ffp0 = 1;
    } else if(searchPrefix == "KC2TE") {
        jtdxEntity = "KP4";
        ffp0 = 1;
    } else if(searchPrefix == "KC5FWS") {
        jtdxEntity = "KP4";
        ffp0 = 1;
    } else if(searchPrefix == "KF5YGN") {
        jtdxEntity = "KP4";
        ffp0 = 1;
    } else if(searchPrefix == "KF5YGX") {
        jtdxEntity = "KP4";
        ffp0 = 1;
    } else if(searchPrefix == "KG6WWV") {
        jtdxEntity = "KP4";
        ffp0 = 1;
    } else if(searchPrefix == "KH2RU") {
        jtdxEntity = "KP4";
        ffp0 = 1;
    } else if(searchPrefix == "KI5KQH") {
        jtdxEntity = "KP4";
        ffp0 = 1;
    } else if(searchPrefix == "KM4ZWY") {
        jtdxEntity = "KP4";
        ffp0 = 1;
    }
}



void LogQSO::get_entity_from_Unique_callsign_LMN ()
{
    if(searchPrefix == "LU3HRS/Z") {
        jtdxEntity = "CE9";
        ffp0 = 1;
    } else if(searchPrefix == "MM0LSM") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM0NQY") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM0VIK") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM0XAU") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM0ZAL") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM0ZCG") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM0ZRC") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM1FEO") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM1FJM") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM3VQO") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM5PSL") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM5YLO") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM6BDU") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM6BZQ") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM6IKB") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM6IMB") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM6MFA") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM6PTE") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM6SJK") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM6YLO") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM6ZBG") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM6ZDW") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM7CGR") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM8A") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MS0ZCG") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MS0ZET") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM0DHQ/NHS") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM3AWD/NHS") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM3DDQ/NHS") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM7WAB/NHS") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "N0SMX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N1JM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N1XK") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N2AU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N2BJ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N2IC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N2JNR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N2NL") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N3BB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N3CI") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N3RA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N3RC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N3ZZ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4ARO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4AU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4BAA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4BCD") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4DW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4EL") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4JRG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4KC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4KH") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4NA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4NO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4OGW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4QS") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4SL") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4TZ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4UC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4UW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4VI") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4VV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4WE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4ZY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4ZZ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N5CR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N5CW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N5DX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N5KO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N5RP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N5SMQ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N5TB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N5TOO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N5YT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N5ZO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N6AR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N6DW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N6RSH") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N7DR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N7IP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N7IV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N7MZW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N7NG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N7RCS") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N7US") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N7WY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N7ZZ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N8AID") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N8GU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N8II") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N8NA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N8NN") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N8OO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N8RA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N8WXQ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N9CIQ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N9GB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N9HDE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N9JF") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N9NA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N9NB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N9NC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N9NM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N9OU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N9RV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N9SB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N9VPV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NA5NN") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "ND2T") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "ND3N") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "ND4Y") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NE8P") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NE9U") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NF4J") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NG7A") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NH6L") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NH6T") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NI7R") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NJ4P") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NJ8J") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NJ8M") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NK7U") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NK8Q") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NL7CQ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NL7D") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NL7QC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NL7WA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NL7XM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NN1N") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NN4NT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NN5O") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NN7A") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NN7CW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NN9DD") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NO9E") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NP2GG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NP3FB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NP3K") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NQ6N") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NR4L") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NR5W") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NR7DX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NS2X") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NS4X") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NT0K") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NW2P") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NW8U") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NX1P") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NX3U") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NY6DX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NZ6T") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NZ7Q") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NH2B") {
        jtdxEntity = "KH0";
        ffp0 = 1;
    } else if(searchPrefix == "N0VYO") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "N3GWR") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "N4BER") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "N7JRO") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "N7OBR") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "NB6R") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "ND1A") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "NR0G") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "N0JOB") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "N4DBX") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "N7CGC") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "N7DUD") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "N7ELD") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "NH2LS") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "N2FVA") {
        jtdxEntity = "KP4";
        ffp0 = 1;
    } else if(searchPrefix == "N4MMT") {
        jtdxEntity = "KP4";
        ffp0 = 1;
    } else if(searchPrefix == "N4NDL") {
        jtdxEntity = "KP4";
        ffp0 = 1;
    } else if(searchPrefix == "N8MQ") {
        jtdxEntity = "KP4";
        ffp0 = 1;
    } else if(searchPrefix == "LU1AW/X") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU1HB/J") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU1JGU/J") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU2DVI/H") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU3DVN/X") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU4AA/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU4AA/X") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU4ARU/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU6FLZ/F") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LX9S/J") {
        jtdxEntity = "LX";
        ffp0 = 1;
    }
}



void LogQSO::get_entity_from_Unique_callsign_OPQRSTUV ()
{
    if(searchPrefix == "VERSION") {
        jtdxEntity = "4W";
        ffp0 = 1;
    } else if(searchPrefix == "RI1ANC") {
        jtdxEntity = "CE9";
        ffp0 = 1;
    } else if(searchPrefix == "VP8AL") {
        jtdxEntity = "CE9";
        ffp0 = 1;
    } else if(searchPrefix == "TO10CWO") {
        jtdxEntity = "FG";
        ffp0 = 1;
    } else if(searchPrefix == "TX3X") {
        jtdxEntity = "FK/c";
        ffp0 = 1;
    } else if(searchPrefix == "TO5A") {
        jtdxEntity = "FM";
        ffp0 = 1;
    } else if(searchPrefix == "TO5T") {
        jtdxEntity = "FM";
        ffp0 = 1;
    } else if(searchPrefix == "TO7A") {
        jtdxEntity = "FM";
        ffp0 = 1;
    } else if(searchPrefix == "TX0T") {
        jtdxEntity = "FO";
        ffp0 = 1;
    } else if(searchPrefix == "TX2A") {
        jtdxEntity = "FO/a";
        ffp0 = 1;
    } else if(searchPrefix == "TX5P") {
        jtdxEntity = "FO/c";
        ffp0 = 1;
    } else if(searchPrefix == "TO1A") {
        jtdxEntity = "FY";
        ffp0 = 1;
    } else if(searchPrefix == "PE1BOJ/J") {
        jtdxEntity = "PA";
        ffp0 = 1;
    } else if(searchPrefix == "SV2JAO/J") {
        jtdxEntity = "SV";
        ffp0 = 1;
    } else if(searchPrefix == "SV2ASP/A") {
        jtdxEntity = "SV/a";
        ffp0 = 1;
    } else if(searchPrefix == "SV2RSG/A") {
        jtdxEntity = "SV/a";
        ffp0 = 1;
    } else if(searchPrefix == "SV0XAZ") {
        jtdxEntity = "SV9";
        ffp0 = 1;
    } else if(searchPrefix == "TA1C/2") {
        jtdxEntity = "TA";
        ffp0 = 1;
    } else if(searchPrefix == "TA1CX/2") {
        jtdxEntity = "TA";
        ffp0 = 1;
    } else if(searchPrefix == "TA1D/3") {
        jtdxEntity = "TA";
        ffp0 = 1;
    } else if(searchPrefix == "TA1D/4") {
        jtdxEntity = "TA";
        ffp0 = 1;
    } else if(searchPrefix == "TA1FA/2") {
        jtdxEntity = "TA";
        ffp0 = 1;
    } else if(searchPrefix == "TA1HZ/2") {
        jtdxEntity = "TA";
        ffp0 = 1;
    } else if(searchPrefix == "TA1UT/3") {
        jtdxEntity = "TA";
        ffp0 = 1;
    } else if(searchPrefix == "TA6CQ/1") {
        jtdxEntity = "TA";
        ffp0 = 1;
    } else if(searchPrefix == "R7AB/P") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RA9UUY/6") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RT9T/3") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R0AI/3") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R100UD") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4HAT") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4HC") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4HCE") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4HCZ") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4HD") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4HDC") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4HDR") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4HL") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4IC") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4ID") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4II") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4IK") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4IM") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4IN") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4IO") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4IT") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R925RZ") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RA4HL") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RA4NCC") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RC4HT") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RC4I") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RC8C/6") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RJ4I") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RJ4P") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RK4HM") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RK4P") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RM4I") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RM4R") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RN2FA/3") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RN4HFJ") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RN4HIF") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RT30DX") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RT9K/6") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RU4HD") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RU4HP") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RU4I") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RU9CK/7") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RW4HM") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RW4HTK") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RW4HW") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RW4HZ") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RW9WJ/4") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RX9KT/6") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UA3LMR/P") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UA4H") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UA4HBM") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UA4HGL") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UA4HIP") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UA4HRZ") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UA4HY") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UA4NF") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UA4PN") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UA4RF") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UA9CSA/1") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UC4I") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UI4I") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R2MWO") {
        jtdxEntity = "UA2";
        ffp0 = 1;
    } else if(searchPrefix == "RN1M/P") {
        jtdxEntity = "UA2";
        ffp0 = 1;
    } else if(searchPrefix == "RV30DX") {
        jtdxEntity = "UA2";
        ffp0 = 1;
    } else if(searchPrefix == "R05SOTA") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "R0WA/P") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "R1FW/0") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "R2ET/9") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "R30EMER") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "R30MDXC") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "R8MZ/9") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "R9GM/8") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "RA/UT5IA") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "RA0QK/8") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "RA4RU/9") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "RM30DX") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "RN1CR/0") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "RN9S") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "RQ30DX") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "RT8T") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "RT9S") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "RV7B/9") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "RX30DX") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "RX6DL/8") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "RY30DX") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "RZ30DX") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "UD6AOP/0") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "VER20201112") {
        jtdxEntity = "VE";
        ffp0 = 1;
    } else if(searchPrefix == "VA2VVV") {
        jtdxEntity = "VE";
        ffp0 = 1;
    } else if(searchPrefix == "VE2CSI") {
        jtdxEntity = "VE";
        ffp0 = 1;
    } else if(searchPrefix == "VE2EKA") {
        jtdxEntity = "VE";
        ffp0 = 1;
    } else if(searchPrefix == "VE2FK") {
        jtdxEntity = "VE";
        ffp0 = 1;
    } else if(searchPrefix == "VE2IDX") {
        jtdxEntity = "VE";
        ffp0 = 1;
    } else if(searchPrefix == "VE2IM") {
        jtdxEntity = "VE";
        ffp0 = 1;
    } else if(searchPrefix == "VE2TKH") {
        jtdxEntity = "VE";
        ffp0 = 1;
    } else if(searchPrefix == "VY0AA") {
        jtdxEntity = "VE";
        ffp0 = 1;
    } else if(searchPrefix == "VY0PW") {
        jtdxEntity = "VE";
        ffp0 = 1;
    } else if(searchPrefix == "VK65PFA") {
        jtdxEntity = "VK";
        ffp0 = 1;
    } else if(searchPrefix == "VK0EK") {
        jtdxEntity = "VK0H";
        ffp0 = 1;
    } else if(searchPrefix == "VK0AI") {
        jtdxEntity = "VK0M";
        ffp0 = 1;
    } else if(searchPrefix == "VK3YQS/9") {
        jtdxEntity = "VK9L";
        ffp0 = 1;
    } else if(searchPrefix == "VK3YQS/VK9") {
        jtdxEntity = "VK9L";
        ffp0 = 1;
    } else if(searchPrefix == "VP6D") {
        jtdxEntity = "VP6/d";
        ffp0 = 1;
    } else if(searchPrefix == "VP8CA") {
        jtdxEntity = "VP8/g";
        ffp0 = 1;
    } else if(searchPrefix == "VP8PJ") {
        jtdxEntity = "VP8/o";
        ffp0 = 1;
    } else if(searchPrefix == "VP8DXU") {
        jtdxEntity = "VP8/s";
        ffp0 = 1;
    }
}



void LogQSO::get_entity_from_Unique_callsign_WXYZ ()
{
    if(searchPrefix == "XQ6CFX") {
        jtdxEntity = "CE";
        ffp0 = 1;
    } else if(searchPrefix == "XQ6OA") {
        jtdxEntity = "CE";
        ffp0 = 1;
    } else if(searchPrefix == "W0BR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W0NA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W0PV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W0QQG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W0RIC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W0YK") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W0ZP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W1GKT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W1NN") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W1PDI") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W1PR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W1RH") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W1SRD") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W2ACY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W2GS") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W2VJN") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W3CB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W3HDH") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W3HKK") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W3NX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W3TB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4BCG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4DAN") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4ER") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4GKM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4KW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4LC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4NBS") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4NI") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4NNF") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4NZ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4PF") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4RYW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4TLK") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4TTM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4UT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W5JR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W5MX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W5NZ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W5UE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W5UJ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W5VE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W5VS") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W6DVS") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W6GMT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W6KGP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W6LFB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W6NWS") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W6SFG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W6UB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W6XR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W7DXX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W7EE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W7GKF") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W7HJ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W7II") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W7IMP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W7IY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W7RY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W7UT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W8AT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W8FJ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W8FN") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W8HAP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W8HGH") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W8LYJ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W8OV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W8TK") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W9CF") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W9DC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W9ET") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W9FI") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W9JA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W9JEF") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W9KKN") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W9MAF") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W9PL") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W9RM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W9RNY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WA0LJM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WA0WWW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WA1FCN") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WA1UJU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WA2VYA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WA3C") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WA5POK") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WA8KAN") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WA8OJR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WA8ZBT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WB3JFS") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WB4YDY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WB5WAJ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WB8BPU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WB8YYY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WB9QAF") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WC7S") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WE5P") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WE6EZ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WF7T") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WF9A") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WH0AI") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WH6AQ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WH6LE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WH7R") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WJ4HCP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WJ9B") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WL5H") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WL7OU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WM5DX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WN7S") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WN7Y") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WO7U") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WP2J") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WP3ME") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WQ5L") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WR3O") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WS6K") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WS6X") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WS7X") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WS9M") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WT2P") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WT7TT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WT8WV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WU0B") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WU9B") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WV4P") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WW4R") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WW5M") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WX4W") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WX5S") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WY6K") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WY7FD") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WZ1Y") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WZ4F") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WZ7I") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WZ8T") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W1ETT") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "W1JJS") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "W6QPV") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "W7NX") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "W7WKS") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "WA6AW") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "WA6CZL") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "WA6QDQ") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "WA7WSU") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "WB4JTT") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "WK1K") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "W1LYD") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "W2KRZ") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "W3MKG") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "W7EGG") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "WA1FVJ") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "WA1OUS") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "WA4RRE") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "WA7B") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "W4LIS") {
        jtdxEntity = "KP2";
        ffp0 = 1;
    }
}



void LogQSO::get_thwCode_from_jtdxEntity ()
{

     if(jtdxEntity == "1A") {
          thwCode ="501A";
          thwEntityName ="Sov Mil Order of Malta";
     } else if(jtdxEntity == "1S") {
               thwCode ="502A";
               thwEntityName ="Spratly Islands";
     } else if(jtdxEntity == "3A") {
               thwCode ="503A";
               thwEntityName ="Monaco";
     } else if(jtdxEntity == "3B6") {
               thwCode ="504A";
               thwEntityName ="Agalega & St. Brandon";
     } else if(jtdxEntity == "3B8") {
               thwCode ="505A";
               thwEntityName ="Mauritius";
     } else if(jtdxEntity == "3B9") {
               thwCode ="506A";
               thwEntityName ="Rodriguez Island";
     } else if(jtdxEntity == "3C") {
               thwCode ="507A";
               thwEntityName ="Equatorial Guinea";
     } else if(jtdxEntity == "3C0") {
               thwCode ="508A";
               thwEntityName ="Annobon Island";
     } else if(jtdxEntity == "3D2") {
               thwCode ="509A";
               thwEntityName ="Fiji";
     } else if(jtdxEntity == "3D2/c") {
               thwCode ="510A";
               thwEntityName ="Conway Reef";
     } else if(jtdxEntity == "3D2/r") {
               thwCode ="511A";
               thwEntityName ="Rotuma Island";
     } else if(jtdxEntity == "3DA") {
               thwCode ="512A";
               thwEntityName ="Swaziland";
     } else if(jtdxEntity == "3V") {
               thwCode ="513A";
               thwEntityName ="Tunisia";
     } else if(jtdxEntity == "3W") {
               thwCode ="514A";
               thwEntityName ="Vietnam";
     } else if(jtdxEntity == "3X") {
               thwCode ="515A";
               thwEntityName ="Guinea";
     } else if(jtdxEntity == "3Y/b") {
               thwCode ="516A";
               thwEntityName ="Bouvet";
     } else if(jtdxEntity == "3Y/p") {
               thwCode ="517A";
               thwEntityName ="Peter 1 Island";
     } else if(jtdxEntity == "4J") {
               thwCode ="739A";
               thwEntityName ="Azerbaijan";
     } else if(jtdxEntity == "4L") {
               thwCode ="730A";
               thwEntityName ="Georgia";
     } else if(jtdxEntity == "4O") {
               thwCode ="851A";
               thwEntityName ="Montenegro";
     } else if(jtdxEntity == "4S") {
               thwCode ="519A";
               thwEntityName ="Sri Lanka";
     } else if(jtdxEntity == "4U1I") {
               thwCode ="520A";
               thwEntityName ="ITU HQ";
     } else if(jtdxEntity == "4U1U") {
               thwCode ="521A";
               thwEntityName ="United Nations HQ";
     } else if(jtdxEntity == "4W") {
               thwCode ="849A";
               thwEntityName ="Timor - Leste";
     } else if(jtdxEntity == "4X") {
               thwCode ="523A";
               thwEntityName ="Israel";
     } else if(jtdxEntity == "5A") {
               thwCode ="524A";
               thwEntityName ="Libya";
     } else if(jtdxEntity == "5B") {
               thwCode ="525A";
               thwEntityName ="Cyprus";
     } else if(jtdxEntity == "5H") {
               thwCode ="526A";
               thwEntityName ="Tanzania";
     } else if(jtdxEntity == "5N") {
               thwCode ="527A";
               thwEntityName ="Nigeria";
     } else if(jtdxEntity == "5R") {
               thwCode ="528A";
               thwEntityName ="Madagascar";
     } else if(jtdxEntity == "5T") {
               thwCode ="529A";
               thwEntityName ="Mauritania";
     } else if(jtdxEntity == "5U") {
               thwCode ="530A";
               thwEntityName ="Niger";
     } else if(jtdxEntity == "5V") {
               thwCode ="531A";
               thwEntityName ="Togo";
     } else if(jtdxEntity == "5W") {
               thwCode ="532A";
               thwEntityName ="Samoa";
     } else if(jtdxEntity == "5X") {
               thwCode ="533A";
               thwEntityName ="Uganda";
     } else if(jtdxEntity == "5Z") {
               thwCode ="534A";
               thwEntityName ="Kenya";
     } else if(jtdxEntity == "6W") {
               thwCode ="535A";
               thwEntityName ="Senegal";
     } else if(jtdxEntity == "6Y") {
               thwCode ="536A";
               thwEntityName ="Jamaica";
     } else if(jtdxEntity == "7O") {
               thwCode ="537A";
               thwEntityName ="Yemen";
     } else if(jtdxEntity == "7P") {
               thwCode ="538A";
               thwEntityName ="Lesotho";
     } else if(jtdxEntity == "7Q") {
               thwCode ="539A";
               thwEntityName ="Malawi";
     } else if(jtdxEntity == "7X") {
               thwCode ="540A";
               thwEntityName ="Algeria";
     } else if(jtdxEntity == "8P") {
               thwCode ="541A";
               thwEntityName ="Barbados";
     } else if(jtdxEntity == "8Q") {
               thwCode ="542A";
               thwEntityName ="Maldives";
     } else if(jtdxEntity == "8R") {
               thwCode ="543A";
               thwEntityName ="Guyana";
     } else if(jtdxEntity == "9A") {
               thwCode ="830A";
               thwEntityName ="Croatia";
     } else if(jtdxEntity == "9G") {
               thwCode ="544A";
               thwEntityName ="Ghana";
     } else if(jtdxEntity == "9H") {
               thwCode ="545A";
               thwEntityName ="Malta";
     } else if(jtdxEntity == "9J") {
               thwCode ="546A";
               thwEntityName ="Zambia";
     } else if(jtdxEntity == "9K") {
               thwCode ="547A";
               thwEntityName ="Kuwait";
     } else if(jtdxEntity == "9L") {
               thwCode ="548A";
               thwEntityName ="Sierra Leone";
     } else if(jtdxEntity == "9M2") {
               thwCode ="549A";
               thwEntityName ="West Malaysia";
     } else if(jtdxEntity == "9M6") {
               thwCode ="550A";
               thwEntityName ="East Malaysia";
     } else if(jtdxEntity == "9N") {
               thwCode ="551A";
               thwEntityName ="Nepal";
     } else if(jtdxEntity == "9Q") {
               thwCode ="552A";
               thwEntityName ="Dem. Rep. of the Congo";
     } else if(jtdxEntity == "9U") {
               thwCode ="553A";
               thwEntityName ="Burundi";
     } else if(jtdxEntity == "9V") {
               thwCode ="554A";
               thwEntityName ="Singapore";
     } else if(jtdxEntity == "9X") {
               thwCode ="555A";
               thwEntityName ="Rwanda";
     } else if(jtdxEntity == "9Y") {
               thwCode ="556A";
               thwEntityName ="Trinidad & Tobago";
     } else if(jtdxEntity == "A2") {
               thwCode ="557A";
               thwEntityName ="Botswana";
     } else if(jtdxEntity == "A3") {
               thwCode ="558A";
               thwEntityName ="Tonga";
     } else if(jtdxEntity == "A4") {
               thwCode ="559A";
               thwEntityName ="Oman";
     } else if(jtdxEntity == "A5") {
               thwCode ="560A";
               thwEntityName ="Bhutan";
     } else if(jtdxEntity == "A6") {
               thwCode ="561A";
               thwEntityName ="United Arab Emirates";
     } else if(jtdxEntity == "A7") {
               thwCode ="562A";
               thwEntityName ="Qatar";
     } else if(jtdxEntity == "A9") {
               thwCode ="563A";
               thwEntityName ="Bahrain";
     } else if(jtdxEntity == "AP") {
               thwCode ="564A";
               thwEntityName ="Pakistan";
     } else if(jtdxEntity == "BS7") {
               thwCode ="843A";
               thwEntityName ="Scarborough Reef";
     } else if(jtdxEntity == "BV") {
               thwCode ="566A";
               thwEntityName ="Taiwan";
     } else if(jtdxEntity == "BV9P") {
               thwCode ="842A";
               thwEntityName ="Pratas Island";
     } else if(jtdxEntity == "BY") {
               thwCode ="565A";
               thwEntityName ="China";
     } else if(jtdxEntity == "C2") {
               thwCode ="567A";
               thwEntityName ="Nauru";
     } else if(jtdxEntity == "C3") {
               thwCode ="568A";
               thwEntityName ="Andorra";
     } else if(jtdxEntity == "C5") {
               thwCode ="569A";
               thwEntityName ="The Gambia";
     } else if(jtdxEntity == "C6") {
               thwCode ="570A";
               thwEntityName ="Bahamas";
     } else if(jtdxEntity == "C9") {
               thwCode ="571A";
               thwEntityName ="Mozambique";
     } else if(jtdxEntity == "CE") {
               thwCode ="572A";
               thwEntityName ="Chile";
     } else if(jtdxEntity == "CE0X") {
               thwCode ="574A";
               thwEntityName ="San Felix & San Ambrosio";
     } else if(jtdxEntity == "CE0Y") {
               thwCode ="573A";
               thwEntityName ="Easter Island";
     } else if(jtdxEntity == "CE0Z") {
               thwCode ="575A";
               thwEntityName ="Juan Fernandez Islands";
     } else if(jtdxEntity == "CE9") {
               thwCode ="826A";
               thwEntityName ="Antarctica";
     } else if(jtdxEntity == "CM") {
               thwCode ="577A";
               thwEntityName ="Cuba";
     } else if(jtdxEntity == "CN") {
               thwCode ="576A";
               thwEntityName ="Morocco";
     } else if(jtdxEntity == "CP") {
               thwCode ="578A";
               thwEntityName ="Bolivia";
     } else if(jtdxEntity == "CT") {
               thwCode ="579A";
               thwEntityName ="Portugal";
     } else if(jtdxEntity == "CT3") {
               thwCode ="580A";
               thwEntityName ="Madeira Islands";
     } else if(jtdxEntity == "CU") {
               thwCode ="581A";
               thwEntityName ="Azores";
     } else if(jtdxEntity == "CX") {
               thwCode ="582A";
               thwEntityName ="Uruguay";
     } else if(jtdxEntity == "CY0") {
               thwCode ="583A";
               thwEntityName ="Sable Island";
     } else if(jtdxEntity == "CY9") {
               thwCode ="584A";
               thwEntityName ="St. Paul Island";
     } else if(jtdxEntity == "D2") {
               thwCode ="585A";
               thwEntityName ="Angola";
     } else if(jtdxEntity == "D4") {
               thwCode ="586A";
               thwEntityName ="Cape Verde";
     } else if(jtdxEntity == "D6") {
               thwCode ="587A";
               thwEntityName ="Comoros";
     } else if(jtdxEntity == "DL") {
               thwCode ="588A";
               thwEntityName ="Fed. Rep. of Germany";
     } else if(jtdxEntity == "DU") {
               thwCode ="589A";
               thwEntityName ="Philippines";
     } else if(jtdxEntity == "E3") {
               thwCode ="841A";
               thwEntityName ="Eritrea";
     } else if(jtdxEntity == "E4") {
               thwCode ="847A";
               thwEntityName ="Palestine";
     } else if(jtdxEntity == "E5/n") {
               thwCode ="813A";
               thwEntityName ="North Cook Islands";
     } else if(jtdxEntity == "E5/s") {
               thwCode ="814A";
               thwEntityName ="South Cook Islands";
     } else if(jtdxEntity == "E6") {
               thwCode ="815A";
               thwEntityName ="Niue";
     } else if(jtdxEntity == "E7") {
               thwCode ="837A";
               thwEntityName ="Bosnia-Herzegovina";
     } else if(jtdxEntity == "EA") {
               thwCode ="590A";
               thwEntityName ="Spain";
     } else if(jtdxEntity == "EA6") {
               thwCode ="591A";
               thwEntityName ="Balearic Islands";
     } else if(jtdxEntity == "EA8") {
               thwCode ="592A";
               thwEntityName ="Canary Islands";
     } else if(jtdxEntity == "EA9") {
               thwCode ="593A";
               thwEntityName ="Ceuta & Melilla";
     } else if(jtdxEntity == "EI") {
               thwCode ="594A";
               thwEntityName ="Ireland";
     } else if(jtdxEntity == "EK") {
               thwCode ="731A";
               thwEntityName ="Armenia";
     } else if(jtdxEntity == "EL") {
               thwCode ="595A";
               thwEntityName ="Liberia";
     } else if(jtdxEntity == "EP") {
               thwCode ="596A";
               thwEntityName ="Iran";
     } else if(jtdxEntity == "ER") {
               thwCode ="747A";
               thwEntityName ="Moldova";
     } else if(jtdxEntity == "ES") {
               thwCode ="740A";
               thwEntityName ="Estonia";
     } else if(jtdxEntity == "ET") {
               thwCode ="597A";
               thwEntityName ="Ethiopia";
     } else if(jtdxEntity == "EU") {
               thwCode ="738A";
               thwEntityName ="Belarus";
     } else if(jtdxEntity == "EX") {
               thwCode ="746A";
               thwEntityName ="Kyrgyzstan";
     } else if(jtdxEntity == "EY") {
               thwCode ="744A";
               thwEntityName ="Tajikistan";
     } else if(jtdxEntity == "EZ") {
               thwCode ="742A";
               thwEntityName ="Turkmenistan";
     } else if(jtdxEntity == "F") {
               thwCode ="598A";
               thwEntityName ="France";
     } else if(jtdxEntity == "FG") {
               thwCode ="599A";
               thwEntityName ="Guadeloupe";
     } else if(jtdxEntity == "FH") {
               thwCode ="600A";
               thwEntityName ="Mayotte";
     } else if(jtdxEntity == "FJ") {
               thwCode ="853A";
               thwEntityName ="St. Barthelemy";
     } else if(jtdxEntity == "FK") {
               thwCode ="601A";
               thwEntityName ="New Caledonia";
     } else if(jtdxEntity == "FK/c") {
               thwCode ="848A";
               thwEntityName ="Chesterfield Islands";
     } else if(jtdxEntity == "FM") {
               thwCode ="602A";
               thwEntityName ="Martinique";
     } else if(jtdxEntity == "FO") {
               thwCode ="603A";
               thwEntityName ="French Polynesia";
     } else if(jtdxEntity == "FO/a") {
               thwCode ="845A";
               thwEntityName ="Austral Islands";
     } else if(jtdxEntity == "FO/c") {
               thwCode ="604A";
               thwEntityName ="Clipperton Island";
     } else if(jtdxEntity == "FO/m") {
               thwCode ="846A";
               thwEntityName ="Marquesas Islands";
     } else if(jtdxEntity == "FP") {
               thwCode ="605A";
               thwEntityName ="St. Pierre & Miquelon";
     } else if(jtdxEntity == "FR") {
               thwCode ="606A";
               thwEntityName ="Reunion Island";
     } else if(jtdxEntity == "FS") {
               thwCode ="610A";
               thwEntityName ="St. Martin";
     } else if(jtdxEntity == "FT/g") {
               thwCode ="607A";
               thwEntityName ="Glorioso Islands";
     } else if(jtdxEntity == "FT/j") {
               thwCode ="608A";
               thwEntityName ="Juan de Nova";
     } else if(jtdxEntity == "FT/t") {
               thwCode ="609A";
               thwEntityName ="Tromelin Island";
     } else if(jtdxEntity == "FT/w") {
               thwCode ="611A";
               thwEntityName ="Crozet Island";
     } else if(jtdxEntity == "FT/x") {
               thwCode ="612A";
               thwEntityName ="Kerguelen Islands";
     } else if(jtdxEntity == "FT/z") {
               thwCode ="613A";
               thwEntityName ="Amsterdam & St. Paul Is.";
     } else if(jtdxEntity == "FW") {
               thwCode ="614A";
               thwEntityName ="Wallis & Futuna Islands";
     } else if(jtdxEntity == "FY") {
               thwCode ="615A";
               thwEntityName ="French Guiana";
     } else if(jtdxEntity == "G") {
               thwCode ="616A";
               thwEntityName ="England";
     } else if(jtdxEntity == "GD") {
               thwCode ="617A";
               thwEntityName ="Isle of Man";
     } else if(jtdxEntity == "GI") {
               thwCode ="618A";
               thwEntityName ="Northern Ireland";
     } else if(jtdxEntity == "GJ") {
               thwCode ="619A";
               thwEntityName ="Jersey";
     } else if(jtdxEntity == "GM") {
               thwCode ="620A";
               thwEntityName ="Scotland";
     } else if(jtdxEntity == "GU") {
               thwCode ="621A";
               thwEntityName ="Guernsey";
     } else if(jtdxEntity == "GW") {
               thwCode ="622A";
               thwEntityName ="Wales";
     } else if(jtdxEntity == "H4") {
               thwCode ="623A";
               thwEntityName ="Solomon Islands";
     } else if(jtdxEntity == "H40") {
               thwCode ="844A";
               thwEntityName ="Temotu Province";
     } else if(jtdxEntity == "HA") {
               thwCode ="624A";
               thwEntityName ="Hungary";
     } else if(jtdxEntity == "HB") {
               thwCode ="625A";
               thwEntityName ="Switzerland";
     } else if(jtdxEntity == "HB0") {
               thwCode ="626A";
               thwEntityName ="Liechtenstein";
     } else if(jtdxEntity == "HC") {
               thwCode ="627A";
               thwEntityName ="Ecuador";
     } else if(jtdxEntity == "HC8") {
               thwCode ="628A";
               thwEntityName ="Galapagos Islands";
     } else if(jtdxEntity == "HH") {
               thwCode ="629A";
               thwEntityName ="Haiti";
     } else if(jtdxEntity == "HI") {
               thwCode ="630A";
               thwEntityName ="Dominican Republic";
     } else if(jtdxEntity == "HK") {
               thwCode ="631A";
               thwEntityName ="Colombia";
     } else if(jtdxEntity == "HK0/a") {
               thwCode ="633A";
               thwEntityName ="San Andres & Providencia";
     } else if(jtdxEntity == "HK0/m") {
               thwCode ="632A";
               thwEntityName ="Malpelo Island";
     } else if(jtdxEntity == "HL") {
               thwCode ="634A";
               thwEntityName ="Republic of Korea";
     } else if(jtdxEntity == "HP") {
               thwCode ="635A";
               thwEntityName ="Panama";
     } else if(jtdxEntity == "HR") {
               thwCode ="636A";
               thwEntityName ="Honduras";
     } else if(jtdxEntity == "HS") {
               thwCode ="637A";
               thwEntityName ="Thailand";
     } else if(jtdxEntity == "HV") {
               thwCode ="638A";
               thwEntityName ="Vatican City";
     } else if(jtdxEntity == "HZ") {
               thwCode ="639A";
               thwEntityName ="Saudi Arabia";
     } else if(jtdxEntity == "I") {
               thwCode ="640A";
               thwEntityName ="Italy";
     } else if(jtdxEntity == "IS") {
               thwCode ="641A";
               thwEntityName ="Sardinia";
     } else if(jtdxEntity == "J2") {
               thwCode ="642A";
               thwEntityName ="Djibouti";
     } else if(jtdxEntity == "J3") {
               thwCode ="643A";
               thwEntityName ="Grenada";
     } else if(jtdxEntity == "J5") {
               thwCode ="644A";
               thwEntityName ="Guinea-Bissau";
     } else if(jtdxEntity == "J6") {
               thwCode ="645A";
               thwEntityName ="St. Lucia";
     } else if(jtdxEntity == "J7") {
               thwCode ="646A";
               thwEntityName ="Dominica";
     } else if(jtdxEntity == "J8") {
               thwCode ="647A";
               thwEntityName ="St. Vincent";
     } else if(jtdxEntity == "JA") {
               thwCode ="500A";
               thwEntityName ="Japan";
     } else if(jtdxEntity == "JD/m") {
               thwCode ="648A";
               thwEntityName ="Minami Torishima";
     } else if(jtdxEntity == "JD/o") {
               thwCode ="649A";
               thwEntityName ="Ogasawara";
     } else if(jtdxEntity == "JT") {
               thwCode ="650A";
               thwEntityName ="Mongolia";
     } else if(jtdxEntity == "JW") {
               thwCode ="651A";
               thwEntityName ="Svalbard";
     } else if(jtdxEntity == "JX") {
               thwCode ="652A";
               thwEntityName ="Jan Mayen";
     } else if(jtdxEntity == "JY") {
               thwCode ="653A";
               thwEntityName ="Jordan";
     } else if(jtdxEntity == "K") {
               thwCode ="784A";
               thwEntityName ="United States";
     } else if(jtdxEntity == "KG4") {
               thwCode ="655A";
               thwEntityName ="Guantanamo Bay";
     } else if(jtdxEntity == "KH0") {
               thwCode ="656A";
               thwEntityName ="Mariana Islands";
     } else if(jtdxEntity == "KH1") {
               thwCode ="657A";
               thwEntityName ="Baker & Howland Islands";
     } else if(jtdxEntity == "KH2") {
               thwCode ="658A";
               thwEntityName ="Guam";
     } else if(jtdxEntity == "KH3") {
               thwCode ="659A";
               thwEntityName ="Johnston Island";
     } else if(jtdxEntity == "KH4") {
               thwCode ="660A";
               thwEntityName ="Midway Island";
     } else if(jtdxEntity == "KH5") {
               thwCode ="661A";
               thwEntityName ="Palmyra & Jarvis Islands";
     } else if(jtdxEntity == "KH6") {
               thwCode ="663A";
               thwEntityName ="Hawaii";
     } else if(jtdxEntity == "KH7K") {
               thwCode ="664A";
               thwEntityName ="Kure Island";
     } else if(jtdxEntity == "KH8") {
               thwCode ="665A";
               thwEntityName ="American Samoa";
     } else if(jtdxEntity == "KH8/s") {
               thwCode ="852A";
               thwEntityName ="Swains Island";
     } else if(jtdxEntity == "KH9") {
               thwCode ="666A";
               thwEntityName ="Wake Island";
     } else if(jtdxEntity == "KL") {
               thwCode ="667A";
               thwEntityName ="Alaska";
     } else if(jtdxEntity == "KP1") {
               thwCode ="668A";
               thwEntityName ="Navassa Island";
     } else if(jtdxEntity == "KP2") {
               thwCode ="669A";
               thwEntityName ="US Virgin Islands";
     } else if(jtdxEntity == "KP4") {
               thwCode ="670A";
               thwEntityName ="Puerto Rico";
     } else if(jtdxEntity == "KP5") {
               thwCode ="671A";
               thwEntityName ="Desecheo Island";
     } else if(jtdxEntity == "LA") {
               thwCode ="672A";
               thwEntityName ="Norway";
     } else if(jtdxEntity == "LU") {
               thwCode ="673A";
               thwEntityName ="Argentina";
     } else if(jtdxEntity == "LX") {
               thwCode ="674A";
               thwEntityName ="Luxembourg";
     } else if(jtdxEntity == "LY") {
               thwCode ="748A";
               thwEntityName ="Lithuania";
     } else if(jtdxEntity == "LZ") {
               thwCode ="675A";
               thwEntityName ="Bulgaria";
     } else if(jtdxEntity == "OA") {
               thwCode ="676A";
               thwEntityName ="Peru";
     } else if(jtdxEntity == "OD") {
               thwCode ="677A";
               thwEntityName ="Lebanon";
     } else if(jtdxEntity == "OE") {
               thwCode ="678A";
               thwEntityName ="Austria";
     } else if(jtdxEntity == "OH") {
               thwCode ="679A";
               thwEntityName ="Finland";
     } else if(jtdxEntity == "OH0") {
               thwCode ="680A";
               thwEntityName ="Aland Islands";
     } else if(jtdxEntity == "OJ0") {
               thwCode ="681A";
               thwEntityName ="Market Reef";
     } else if(jtdxEntity == "OK") {
               thwCode ="839A";
               thwEntityName ="Czech Republic";
     } else if(jtdxEntity == "OM") {
               thwCode ="840A";
               thwEntityName ="Slovak Republic";
     } else if(jtdxEntity == "ON") {
               thwCode ="683A";
               thwEntityName ="Belgium";
     } else if(jtdxEntity == "OX") {
               thwCode ="684A";
               thwEntityName ="Greenland";
     } else if(jtdxEntity == "OY") {
               thwCode ="685A";
               thwEntityName ="Faroe Islands";
     } else if(jtdxEntity == "OZ") {
               thwCode ="686A";
               thwEntityName ="Denmark";
     } else if(jtdxEntity == "P2") {
               thwCode ="687A";
               thwEntityName ="Papua New Guinea";
     } else if(jtdxEntity == "P4") {
               thwCode ="688A";
               thwEntityName ="Aruba";
     } else if(jtdxEntity == "P5") {
               thwCode ="689A";
               thwEntityName ="DPR of Korea";
     } else if(jtdxEntity == "PA") {
               thwCode ="690A";
               thwEntityName ="Netherlands";
     } else if(jtdxEntity == "PJ2") {
               thwCode ="854A";
               thwEntityName ="Curacao";
     } else if(jtdxEntity == "PJ4") {
               thwCode ="855A";
               thwEntityName ="Bonaire";
     } else if(jtdxEntity == "PJ5") {
               thwCode ="856A";
               thwEntityName ="Saba & St. Eustatius";
     } else if(jtdxEntity == "PJ7") {
               thwCode ="857A";
               thwEntityName ="Sint Maarten";
     } else if(jtdxEntity == "PY") {
               thwCode ="693A";
               thwEntityName ="Brazil";
     } else if(jtdxEntity == "PY0F") {
               thwCode ="694A";
               thwEntityName ="Fernando de Noronha";
     } else if(jtdxEntity == "PY0S") {
               thwCode ="695A";
               thwEntityName ="St. Peter & St. Paul";
     } else if(jtdxEntity == "PY0T") {
               thwCode ="696A";
               thwEntityName ="Trindade & Martim Vaz";
     } else if(jtdxEntity == "PZ") {
               thwCode ="697A";
               thwEntityName ="Suriname";
     } else if(jtdxEntity == "R1FJ") {
               thwCode ="734A";
               thwEntityName ="Franz Josef Land";
     } else if(jtdxEntity == "S0") {
               thwCode ="698A";
               thwEntityName ="Western Sahara";
     } else if(jtdxEntity == "S2") {
               thwCode ="699A";
               thwEntityName ="Bangladesh";
     } else if(jtdxEntity == "S5") {
               thwCode ="832A";
               thwEntityName ="Slovenia";
     } else if(jtdxEntity == "S7") {
               thwCode ="700A";
               thwEntityName ="Seychelles";
     } else if(jtdxEntity == "S9") {
               thwCode ="701A";
               thwEntityName ="Sao Tome & Principe";
     } else if(jtdxEntity == "SM") {
               thwCode ="702A";
               thwEntityName ="Sweden";
     } else if(jtdxEntity == "SP") {
               thwCode ="703A";
               thwEntityName ="Poland";
     } else if(jtdxEntity == "ST") {
               thwCode ="704A";
               thwEntityName ="Sudan";
     } else if(jtdxEntity == "SU") {
               thwCode ="706A";
               thwEntityName ="Egypt";
     } else if(jtdxEntity == "SV") {
               thwCode ="707A";
               thwEntityName ="Greece";
     } else if(jtdxEntity == "SV/a") {
               thwCode ="708A";
               thwEntityName ="Mount Athos";
     } else if(jtdxEntity == "SV5") {
               thwCode ="709A";
               thwEntityName ="Dodecanese";
     } else if(jtdxEntity == "SV9") {
               thwCode ="736A";
               thwEntityName ="Crete";
     } else if(jtdxEntity == "T2") {
               thwCode ="711A";
               thwEntityName ="Tuvalu";
     } else if(jtdxEntity == "T30") {
               thwCode ="712A";
               thwEntityName ="Western Kiribati";
     } else if(jtdxEntity == "T31") {
               thwCode ="713A";
               thwEntityName ="Central Kiribati";
     } else if(jtdxEntity == "T32") {
               thwCode ="714A";
               thwEntityName ="Eastern Kiribati";
     } else if(jtdxEntity == "T33") {
               thwCode ="715A";
               thwEntityName ="Banaba Island";
     } else if(jtdxEntity == "T5") {
               thwCode ="716A";
               thwEntityName ="Somalia";
     } else if(jtdxEntity == "T7") {
               thwCode ="717A";
               thwEntityName ="San Marino";
     } else if(jtdxEntity == "T8") {
               thwCode ="654A";
               thwEntityName ="Palau";
     } else if(jtdxEntity == "TA") {
               thwCode ="718A";
               thwEntityName ="Asiatic Turkey";
     } else if(jtdxEntity == "TF") {
               thwCode ="719A";
               thwEntityName ="Iceland";
     } else if(jtdxEntity == "TG") {
               thwCode ="710A";
               thwEntityName ="Guatemala";
     } else if(jtdxEntity == "TI") {
               thwCode ="721A";
               thwEntityName ="Costa Rica";
     } else if(jtdxEntity == "TI9") {
               thwCode ="722A";
               thwEntityName ="Cocos Island";
     } else if(jtdxEntity == "TJ") {
               thwCode ="723A";
               thwEntityName ="Cameroon";
     } else if(jtdxEntity == "TK") {
               thwCode ="724A";
               thwEntityName ="Corsica";
     } else if(jtdxEntity == "TL") {
               thwCode ="725A";
               thwEntityName ="Central African Republic";
     } else if(jtdxEntity == "TN") {
               thwCode ="726A";
               thwEntityName ="Republic of the Congo";
     } else if(jtdxEntity == "TR") {
               thwCode ="727A";
               thwEntityName ="Gabon";
     } else if(jtdxEntity == "TT") {
               thwCode ="728A";
               thwEntityName ="Chad";
     } else if(jtdxEntity == "TU") {
               thwCode ="729A";
               thwEntityName ="Cote d'Ivoire";
     } else if(jtdxEntity == "TY") {
               thwCode ="720A";
               thwEntityName ="Benin";
     } else if(jtdxEntity == "TZ") {
               thwCode ="751A";
               thwEntityName ="Mali";
     } else if(jtdxEntity == "UA") {
               thwCode ="733A";
               thwEntityName ="European Russia";
     } else if(jtdxEntity == "UA2") {
               thwCode ="735A";
               thwEntityName ="Kaliningrad";
     } else if(jtdxEntity == "UA9") {
               thwCode ="732A";
               thwEntityName ="Asiatic Russia";
     } else if(jtdxEntity == "UK") {
               thwCode ="743A";
               thwEntityName ="Uzbekistan";
     } else if(jtdxEntity == "UN") {
               thwCode ="745A";
               thwEntityName ="Kazakhstan";
     } else if(jtdxEntity == "UR") {
               thwCode ="737A";
               thwEntityName ="Ukraine";
     } else if(jtdxEntity == "V2") {
               thwCode ="741A";
               thwEntityName ="Antigua & Barbuda";
     } else if(jtdxEntity == "V3") {
               thwCode ="752A";
               thwEntityName ="Belize";
     } else if(jtdxEntity == "V4") {
               thwCode ="753A";
               thwEntityName ="St. Kitts & Nevis";
     } else if(jtdxEntity == "V5") {
               thwCode ="754A";
               thwEntityName ="Namibia";
     } else if(jtdxEntity == "V6") {
               thwCode ="755A";
               thwEntityName ="Micronesia";
     } else if(jtdxEntity == "V7") {
               thwCode ="756A";
               thwEntityName ="Marshall Islands";
     } else if(jtdxEntity == "V8") {
               thwCode ="757A";
               thwEntityName ="Brunei Darussalam";
     } else if(jtdxEntity == "VE") {
               thwCode ="758A";
               thwEntityName ="Canada";
     } else if(jtdxEntity == "VK") {
               thwCode ="759A";
               thwEntityName ="Australia";
     } else if(jtdxEntity == "VK0H") {
               thwCode ="766A";
               thwEntityName ="Heard Island";
     } else if(jtdxEntity == "VK0M") {
               thwCode ="767A";
               thwEntityName ="Macquarie Island";
     } else if(jtdxEntity == "VK9C") {
               thwCode ="763A";
               thwEntityName ="Cocos (Keeling) Islands";
     } else if(jtdxEntity == "VK9L") {
               thwCode ="760A";
               thwEntityName ="Lord Howe Island";
     } else if(jtdxEntity == "VK9M") {
               thwCode ="764A";
               thwEntityName ="Mellish Reef";
     } else if(jtdxEntity == "VK9N") {
               thwCode ="765A";
               thwEntityName ="Norfolk Island";
     } else if(jtdxEntity == "VK9W") {
               thwCode ="761A";
               thwEntityName ="Willis Island";
     } else if(jtdxEntity == "VK9X") {
               thwCode ="762A";
               thwEntityName ="Christmas Island";
     } else if(jtdxEntity == "VP2E") {
               thwCode ="768A";
               thwEntityName ="Anguilla";
     } else if(jtdxEntity == "VP2M") {
               thwCode ="769A";
               thwEntityName ="Montserrat";
     } else if(jtdxEntity == "VP2V") {
               thwCode ="770A";
               thwEntityName ="British Virgin Islands";
     } else if(jtdxEntity == "VP5") {
               thwCode ="771A";
               thwEntityName ="Turks & Caicos Islands";
     } else if(jtdxEntity == "VP6") {
               thwCode ="779A";
               thwEntityName ="Pitcairn Island";
     } else if(jtdxEntity == "VP6/d") {
               thwCode ="850A";
               thwEntityName ="Ducie Island";
     } else if(jtdxEntity == "VP8") {
               thwCode ="772A";
               thwEntityName ="Falkland Islands";
     } else if(jtdxEntity == "VP8/g") {
               thwCode ="773A";
               thwEntityName ="South Georgia Island";
     } else if(jtdxEntity == "VP8/h") {
               thwCode ="776A";
               thwEntityName ="South Shetland Islands";
     } else if(jtdxEntity == "VP8/o") {
               thwCode ="774A";
               thwEntityName ="South Orkney Islands";
     } else if(jtdxEntity == "VP8/s") {
               thwCode ="775A";
               thwEntityName ="South Sandwich Islands";
     } else if(jtdxEntity == "VP9") {
               thwCode ="777A";
               thwEntityName ="Bermuda";
     } else if(jtdxEntity == "VQ9") {
               thwCode ="778A";
               thwEntityName ="Chagos Islands";
     } else if(jtdxEntity == "VR") {
               thwCode ="780A";
               thwEntityName ="Hong Kong";
     } else if(jtdxEntity == "VU") {
               thwCode ="781A";
               thwEntityName ="India";
     } else if(jtdxEntity == "VU4") {
               thwCode ="782A";
               thwEntityName ="Andaman & Nicobar Is.";
     } else if(jtdxEntity == "VU7") {
               thwCode ="783A";
               thwEntityName ="Lakshadweep Islands";
     } else if(jtdxEntity == "XE") {
               thwCode ="785A";
               thwEntityName ="Mexico";
     } else if(jtdxEntity == "XF4") {
               thwCode ="786A";
               thwEntityName ="Revillagigedo";
     } else if(jtdxEntity == "XT") {
               thwCode ="787A";
               thwEntityName ="Burkina Faso";
     } else if(jtdxEntity == "XU") {
               thwCode ="788A";
               thwEntityName ="Cambodia";
     } else if(jtdxEntity == "XW") {
               thwCode ="789A";
               thwEntityName ="Laos";
     } else if(jtdxEntity == "XX9") {
               thwCode ="790A";
               thwEntityName ="Macao";
     } else if(jtdxEntity == "XZ") {
               thwCode ="791A";
               thwEntityName ="Myanmar";
     } else if(jtdxEntity == "YA") {
               thwCode ="793A";
               thwEntityName ="Afghanistan";
     } else if(jtdxEntity == "YB") {
               thwCode ="794A";
               thwEntityName ="Indonesia";
     } else if(jtdxEntity == "YI") {
               thwCode ="795A";
               thwEntityName ="Iraq";
     } else if(jtdxEntity == "YJ") {
               thwCode ="796A";
               thwEntityName ="Vanuatu";
     } else if(jtdxEntity == "YK") {
               thwCode ="797A";
               thwEntityName ="Syria";
     } else if(jtdxEntity == "YL") {
               thwCode ="749A";
               thwEntityName ="Latvia";
     } else if(jtdxEntity == "YN") {
               thwCode ="798A";
               thwEntityName ="Nicaragua";
     } else if(jtdxEntity == "YO") {
               thwCode ="799A";
               thwEntityName ="Romania";
     } else if(jtdxEntity == "YS") {
               thwCode ="801A";
               thwEntityName ="El Salvador";
     } else if(jtdxEntity == "YU") {
               thwCode ="802A";
               thwEntityName ="Serbia";
     } else if(jtdxEntity == "YV") {
               thwCode ="803A";
               thwEntityName ="Venezuela";
     } else if(jtdxEntity == "YV0") {
               thwCode ="804A";
               thwEntityName ="Aves Island";
     } else if(jtdxEntity == "Z2") {
               thwCode ="805A";
               thwEntityName ="Zimbabwe";
     } else if(jtdxEntity == "Z3") {
               thwCode ="838A";
               thwEntityName ="Macedonia";
     } else if(jtdxEntity == "Z6") {
               thwCode ="859A";
               thwEntityName ="Republic of Kosovo";
     } else if(jtdxEntity == "Z8") {
               thwCode ="858A";
               thwEntityName ="Republic of South Sudan";
     } else if(jtdxEntity == "ZA") {
               thwCode ="806A";
               thwEntityName ="Albania";
     } else if(jtdxEntity == "ZB") {
               thwCode ="807A";
               thwEntityName ="Gibraltar";
     } else if(jtdxEntity == "ZC4") {
               thwCode ="808A";
               thwEntityName ="UK Base Areas on Cyprus";
     } else if(jtdxEntity == "ZD7") {
               thwCode ="809A";
               thwEntityName ="St. Helena";
     } else if(jtdxEntity == "ZD8") {
               thwCode ="810A";
               thwEntityName ="Ascension Island";
     } else if(jtdxEntity == "ZD9") {
               thwCode ="811A";
               thwEntityName ="Tristan da Cunha & Gough";
     } else if(jtdxEntity == "ZF") {
               thwCode ="812A";
               thwEntityName ="Cayman Islands";
     } else if(jtdxEntity == "ZK3") {
               thwCode ="816A";
               thwEntityName ="Tokelau Islands";
     } else if(jtdxEntity == "ZL") {
               thwCode ="817A";
               thwEntityName ="New Zealand";
     } else if(jtdxEntity == "ZL7") {
               thwCode ="818A";
               thwEntityName ="Chatham Islands";
     } else if(jtdxEntity == "ZL8") {
               thwCode ="819A";
               thwEntityName ="Kermadec Islands";
     } else if(jtdxEntity == "ZL9") {
               thwCode ="820A";
               thwEntityName ="N.Z. Subantarctic Is.";
     } else if(jtdxEntity == "ZP") {
               thwCode ="821A";
               thwEntityName ="Paraguay";
     } else if(jtdxEntity == "ZS") {
               thwCode ="822A";
               thwEntityName ="South Africa";
     } else if(jtdxEntity == "ZS8") {
               thwCode ="824A";
               thwEntityName ="Pr. Edward & Marion Is.";
     }
}


// <--- ja2bqx


